<?php
/**
 * Plugin Name: Dynamic Taxes for WooCommerce
 * Plugin URI: https://www.dorzki.io/adding-taxes-dynamically-in-woocommerce/?utm_source=wordpress-plugin&utm_medium=plugin-uri&utm_campaign=tutorial-code
 * Description: Add taxes dynamically according to product type and quantity.
 * Version: 1.0.0
 * Requires at least: 5.0
 * Requires PHP: 7.4
 * Author: dorzki
 * Author URI: https://www.dorzki.io/?utm_source=wordpress-plugin&utm_medium=author-uri&utm_campaign=tutorial-code
 * License: GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: dorzki-wc-dynamic-taxes
 *
 * @package    WordPress
 * @subpackage Plugins
 * @author     Dor Zuberi <admin@dorzki.io>
 * @link       https://www.dorzki.io
 * @version    1.0.0
 */

// Block if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Plugin constants
if ( ! defined( 'DRZK_DYNAMIC_TAXES_PATH' ) ) {
	define( 'DRZK_DYNAMIC_TAXES_PATH', __DIR__ );
}


/**
 * Checks if WooCommerce is installed and activated.
 */
function dorzki_wc_dynamic_taxes_check_required_plugins(): void {
	if ( ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true ) ) {
		add_action( 'admin_notices', 'dorzki_wc_dynamic_taxes_display_woocommerce_notice' );

		return;
	}

	include_once DRZK_DYNAMIC_TAXES_PATH . '/class-plugin.php';
}

add_action( 'plugins_loaded', 'dorzki_wc_dynamic_taxes_check_required_plugins' );


/**
 * Displays an admin notice for WooCommerce.
 */
function dorzki_wc_dynamic_taxes_display_woocommerce_notice(): void {
	$notice = sprintf(
	/* translators: 1: WooCommerce 2: Plugin Name */
		esc_html__( '"%1$s" is required to be installed and activated in order to use "%2$s".', 'dorzki-wc-dynamic-taxes' ),
		'<strong>' . esc_html__( 'WooCommerce', 'dorzki-wc-dynamic-taxes' ) . '</strong>',
		'<strong>' . esc_html__( 'Dynamic Taxes for WooCommerce', 'dorzki-wc-dynamic-taxes' ) . '</strong>'
	);

	echo wp_kses_post( "<div class='notice notice-error'><p>{$notice}</p></div>" );
}
